pub struct RingLoss {
pub overwritten: u64,
pub unavailable: u64,
}Expand description
Counters skipped while walking a ring.
Fields
overwritten: u64Counters older than the current ring window.
Counters inside the readable window whose slot was definitively unavailable, wrapped, corrupt, or carried an unexpected frame id.
Implementations