ShmRingLaneView

Struct ShmRingLaneView 

pub struct ShmRingLaneView<'a> { /* private fields */ }
One physical lane of a ShmRingView.

Implementations

Source

impl ShmRingLaneView<'_>

pub fn index(self) -> usize

pub fn head(self) -> u64

Snapshot the currently visible committed/reserved head.

pub fn retained_range(self) -> Range<u64> ⓘ

Counter range that may still be retained at the observed head.

pub fn read_at(self, counter: u64) -> Option<Frame>

Read the exact counter if its frame is still committed in this lane.

pub fn read_head(self) -> Option<Frame>

Read the frame immediately below the observed head.