RingRead

Enum RingRead 

pub enum RingRead {
    Ready(Frame),
    Pending,
    Unavailable,
}
Result of reading one logical counter from a ring source.

Variants



Ready(Frame)

The expected counter is fully committed and safe to consume.



Pending

The counter has been claimed but may still be in flight. A cursor must stay on this counter and retry later.



Unavailable

The counter can no longer be read from this slot.